from aquests.lib.attrdict import AttrDict

class HTTPResponse:
	def __init__ (self, handler):
		self.response = handler.response
		self.request = self.response.request
		self.meta = self.request.meta
		# compet with requests
		self.status_code = self.response.code
		self.status_msg = self.response.msg		
		
	def __getattr__ (self, name):
		return getattr (self.response, name)
	
	
class DBOResponse:
	def __init__ (self, description, expt_class, expt_str, data):
		self.description = description
		self.expt_class = expt_class
		self.expt_str = expt_str
		self.data = data
		self.code, self.msg = 200, "OK"
		
		if expt_class:
			self.code = 500
			self.msg = "%s %s" % (str (expt_class[1:-1], expt_str))
		
		if description:
			assert (len (description) == len (data [0]))		
			cols = [type (col) is tuple and col [0] or col.name for col in description]		
			d = []
			for row in data:
				i = 0
				drow = AttrDict ()
				for name in cols:
					drow [name] = row [i]
					i += 1
				d.append (drow)
			self.data = d
			
		else:
			if type (data) is dict:
				try:
					self.data = AttrDict ()
					for k, v in data.items ():
						self.data [k] = v
				except:
					self.data = data
			else:		
				self.data = data
		
		def read (self):
			return self.data
		
		


import aquests

def request_finished (r):
	args = (r.status_code, r.reason, len (r.content))
	print ("%s %s %d bytes received" % args, r.version)

aquests.configure (10, callback = request_finished)
for i in range (1000): 
	aquests.get ("http://127.0.0.1:5000/")
	#aquests.get ("http://127.0.0.1:5000/images/gif1.gif")
aquests.fetchall ()



class _Method:
	def __init__(self, send, name):
		self.__send = send
		self.__name = name
		
	def __getattr__(self, name):
		return _Method(self.__send, "%s.%s" % (self.__name, name))
		
	def __call__(self, *args):
		return self.__send(self.__name, args)


class Proxy:
	def __init__ (self, command, executor, *args, **kargs):
		self.__command = command
		self.__executor = executor
		self.__args = args
		self.__kargs = kargs		
	
	def __getattr__ (self, name):	  
		return _Method(self.__request, name)
	
	def __request (self, method, params):
		self.__executor (self.__command, method, params, *self.__args, **self.__kargs)
		


FIN    = 0x80
OPCODE = 0x0f
MASKED = 0x80
PAYLOAD_LEN = 0x7f
PAYLOAD_LEN_EXT16 = 0x7e
PAYLOAD_LEN_EXT64 = 0x7f
	
OPCODE_CONTINUATION = 0x0
OPCODE_TEXT = 0x1
OPCODE_BINARY = 0x2
OPCODE_CLOSE = 0x8
OPCODE_PING = 0x9
OPCODE_PONG = 0xa





"""
$Id: Class.py,v 1.6 2002/04/23 12:52:19 anthonybaxter Exp $

 This file is part of the pydns project.
 Homepage: http://pydns.sourceforge.net

 This code is covered by the standard Python License.

 CLASS values (section 3.2.4)
"""


IN = 1          # the Internet
CS = 2          # the CSNET class (Obsolete - used only for examples in
                # some obsolete RFCs)
CH = 3          # the CHAOS class. When someone shows me python running on
                # a Symbolics Lisp machine, I'll look at implementing this.
HS = 4          # Hesiod [Dyer 87]

# QCLASS values (section 3.2.5)

ANY = 255       # any class


# Construct reverse mapping dictionary

_names = dir()
classmap = {}
for _name in _names:
    if _name[0] != '_': classmap[eval(_name)] = _name

def classstr(klass):
    if klass in classmap: return classmap[klass]
    else: return repr(klass)

#
# $Log: Class.py,v $
# Revision 1.6  2002/04/23 12:52:19  anthonybaxter
# cleanup whitespace.
#
# Revision 1.5  2002/03/19 12:41:33  anthonybaxter
# tabnannied and reindented everything. 4 space indent, no tabs.
# yay.
#
# Revision 1.4  2002/03/19 12:26:13  anthonybaxter
# death to leading tabs.
#
# Revision 1.3  2001/08/09 09:08:55  anthonybaxter
# added identifying header to top of each file
#
# Revision 1.2  2001/07/19 06:57:07  anthony
# cvs keywords added
#
#



from . import asynmongo, asynpsycopg2, asynredis

DB_PGSQL = "*postgresql"
DB_SQLITE3 = "*sqlite3"
DB_REDIS = "*redis"
DB_MONGODB = "*mongodb"

def set_timeout (timeout):
	for each in (asynmongo.AsynConnect, asynpsycopg2.AsynConnect, asynredis.AsynConnect):
		each.zombie_timeout = timeout		

